/**
 * Inspector Controls
 */

import map from 'lodash/map';
import mb2blocks_get_icons from './../../helper/helper_icons';

const {
	compose,
	withState
} = wp.compose;

// Setup the block
const { __ } = wp.i18n;
const { Component } = wp.element;

// Import block components
const {
  InspectorControls,
  ColorPalette,
  PanelColorSettings,
  MediaUpload,
} = wp.editor;

// Import Inspector components
const {
	Toolbar,
	Button,
	PanelBody,
	PanelTabs,
	FormToggle,
	RangeControl,
	SelectControl,
	ToggleControl,
    TextControl,
	IconButton,
	Tooltip,
    Spinner
} = wp.components;

export default class Inspector extends Component {

	constructor( props ) {
		super( ...arguments );
	}

	render() {

		// Setup the attributes
		const {
            icon,
			icon_type
        } = this.props.attributes;

		const { clientId, attributes, setAttributes } = this.props;

        const onSelectImage = img => {
			setAttributes();
		};

		const onRemoveImage = () => {
			setAttributes();
		}

        withState();

        const updateButton = ( value, index ) => {
			const updatedData = data.map( ( item, i ) => {
				if ( index === i ) {
					item = { ...item, ...value };
				}
				return item;
			});

			props.setAttributes({
				data: updatedData
			});
		};

		// Get font icons
		const icons = mb2blocks_get_icons( icon_type );
		const activeEmptyClass = icon === '' ? ' active' : '';
		return (
			<InspectorControls key="inspector">
				<PanelBody title={ __( 'Icon' ) } initialOpen={ false }>
					<SelectControl
						label={ __( 'Icon Type' ) }
						value={ icon_type }
						onChange= { ( value ) => this.props.setAttributes( { icon_type: value } ) }
						options={ [
							{ value: 'fa', label: __( 'Font Awesome' ) },
							{ value: 'glyphicon', label: __( 'Glyphicon' ) },
							{ value: '7-stroke', label: __( '7 Stroke' ) },
							{ value: 'line', label: __( 'Line Icons' ) }
						] }
					/>
					<Tooltip text={ __( 'No icon', 'mb2blocks' ) }>
						<Button
							isLarge
							className = { 'mb2blocks-icon-button empty-icon' + activeEmptyClass }
							onClick= { ( ) => this.props.setAttributes( { icon: '' } ) }
						>
							<span className="editor-block-types-list__item-icon"></span>
						</Button>
					</Tooltip>
					{ icons.length > 0 ?
						icons.map( ( item ) => {
							let activeClass = icon === item.classname ? ' active' : '';
							return (
								<Tooltip text={ item.name }>
									<Button
										isLarge
										className = { 'mb2blocks-icon-button' + activeClass }
										onClick= { ( ) => this.props.setAttributes( { icon: item.classname } ) }
									>
										<span className="editor-block-types-list__item-icon">
											<i class = { item.classname }></i>
										</span>
									</Button>
								</Tooltip>
							);
						}
					) :
						<span>{ __( 'No icons' ) } </span>
					}
				</PanelBody>
			</InspectorControls>
		);
	}
}
